pub struct Syscon { /* private fields */ }Expand description
SYSCON
Implementations
Sourceimpl Syscon
impl Syscon
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn memoryremap(self) -> Reg<Memoryremap, RW>
pub const fn memoryremap(self) -> Reg<Memoryremap, RW>
Memory Remap control register
Sourcepub const fn ahbmatprio(self) -> Reg<Ahbmatprio, RW>
pub const fn ahbmatprio(self) -> Reg<Ahbmatprio, RW>
AHB Matrix priority control register Priority values are 3 = highest, 0 = lowest
Sourcepub const fn cpu0stckcal(self) -> Reg<Cpu0stckcal, RW>
pub const fn cpu0stckcal(self) -> Reg<Cpu0stckcal, RW>
System tick calibration for secure part of CPU0
Sourcepub const fn cpu0nstckcal(self) -> Reg<Cpu0nstckcal, RW>
pub const fn cpu0nstckcal(self) -> Reg<Cpu0nstckcal, RW>
System tick calibration for non-secure part of CPU0
Sourcepub const fn cpu1stckcal(self) -> Reg<Cpu1stckcal, RW>
pub const fn cpu1stckcal(self) -> Reg<Cpu1stckcal, RW>
System tick calibration for CPU1
Sourcepub const fn presetctrl0(self) -> Reg<Presetctrl0, RW>
pub const fn presetctrl0(self) -> Reg<Presetctrl0, RW>
Peripheral reset control 0
Sourcepub const fn presetctrl1(self) -> Reg<Presetctrl1, RW>
pub const fn presetctrl1(self) -> Reg<Presetctrl1, RW>
Peripheral reset control 1
Sourcepub const fn presetctrl2(self) -> Reg<Presetctrl2, RW>
pub const fn presetctrl2(self) -> Reg<Presetctrl2, RW>
Peripheral reset control 2
Sourcepub const fn presetctrlset(self, n: usize) -> Reg<Presetctrlset, RW>
pub const fn presetctrlset(self, n: usize) -> Reg<Presetctrlset, RW>
Peripheral reset control set register
Sourcepub const fn presetctrlclr(self, n: usize) -> Reg<Presetctrlclr, RW>
pub const fn presetctrlclr(self, n: usize) -> Reg<Presetctrlclr, RW>
Peripheral reset control clear register
Sourcepub const fn ahbclkctrl0(self) -> Reg<Ahbclkctrl0, RW>
pub const fn ahbclkctrl0(self) -> Reg<Ahbclkctrl0, RW>
AHB Clock control 0
Sourcepub const fn ahbclkctrl1(self) -> Reg<Ahbclkctrl1, RW>
pub const fn ahbclkctrl1(self) -> Reg<Ahbclkctrl1, RW>
AHB Clock control 1
Sourcepub const fn ahbclkctrl2(self) -> Reg<Ahbclkctrl2, RW>
pub const fn ahbclkctrl2(self) -> Reg<Ahbclkctrl2, RW>
AHB Clock control 2
Sourcepub const fn ahbclkctrlset(self, n: usize) -> Reg<Ahbclkctrlset, RW>
pub const fn ahbclkctrlset(self, n: usize) -> Reg<Ahbclkctrlset, RW>
Peripheral reset control register
Sourcepub const fn ahbclkctrlclr(self, n: usize) -> Reg<Ahbclkctrlclr, RW>
pub const fn ahbclkctrlclr(self, n: usize) -> Reg<Ahbclkctrlclr, RW>
Peripheral reset control register
Sourcepub const fn systickclksel0(self) -> Reg<Systickclksel0, RW>
pub const fn systickclksel0(self) -> Reg<Systickclksel0, RW>
System Tick Timer for CPU0 source select
Sourcepub const fn systickclkselx0(self) -> Reg<Systickclkselx0, RW>
pub const fn systickclkselx0(self) -> Reg<Systickclkselx0, RW>
Peripheral reset control register
Sourcepub const fn systickclksel1(self) -> Reg<Systickclksel1, RW>
pub const fn systickclksel1(self) -> Reg<Systickclksel1, RW>
System Tick Timer for CPU1 source select
Sourcepub const fn systickclkselx1(self) -> Reg<Systickclkselx1, RW>
pub const fn systickclkselx1(self) -> Reg<Systickclkselx1, RW>
Peripheral reset control register
Sourcepub const fn traceclksel(self) -> Reg<Traceclksel, RW>
pub const fn traceclksel(self) -> Reg<Traceclksel, RW>
Trace clock source select
Sourcepub const fn ctimerclksel0(self) -> Reg<Ctimerclksel0, RW>
pub const fn ctimerclksel0(self) -> Reg<Ctimerclksel0, RW>
CTimer 0 clock source select
Sourcepub const fn ctimerclkselx0(self) -> Reg<Ctimerclkselx0, RW>
pub const fn ctimerclkselx0(self) -> Reg<Ctimerclkselx0, RW>
Peripheral reset control register
Sourcepub const fn ctimerclksel1(self) -> Reg<Ctimerclksel1, RW>
pub const fn ctimerclksel1(self) -> Reg<Ctimerclksel1, RW>
CTimer 1 clock source select
Sourcepub const fn ctimerclkselx1(self) -> Reg<Ctimerclkselx1, RW>
pub const fn ctimerclkselx1(self) -> Reg<Ctimerclkselx1, RW>
Peripheral reset control register
Sourcepub const fn ctimerclksel2(self) -> Reg<Ctimerclksel2, RW>
pub const fn ctimerclksel2(self) -> Reg<Ctimerclksel2, RW>
CTimer 2 clock source select
Sourcepub const fn ctimerclkselx2(self) -> Reg<Ctimerclkselx2, RW>
pub const fn ctimerclkselx2(self) -> Reg<Ctimerclkselx2, RW>
Peripheral reset control register
Sourcepub const fn ctimerclksel3(self) -> Reg<Ctimerclksel3, RW>
pub const fn ctimerclksel3(self) -> Reg<Ctimerclksel3, RW>
CTimer 3 clock source select
Sourcepub const fn ctimerclkselx3(self) -> Reg<Ctimerclkselx3, RW>
pub const fn ctimerclkselx3(self) -> Reg<Ctimerclkselx3, RW>
Peripheral reset control register
Sourcepub const fn ctimerclksel4(self) -> Reg<Ctimerclksel4, RW>
pub const fn ctimerclksel4(self) -> Reg<Ctimerclksel4, RW>
CTimer 4 clock source select
Sourcepub const fn ctimerclkselx4(self) -> Reg<Ctimerclkselx4, RW>
pub const fn ctimerclkselx4(self) -> Reg<Ctimerclkselx4, RW>
Peripheral reset control register
Sourcepub const fn mainclksela(self) -> Reg<Mainclksela, RW>
pub const fn mainclksela(self) -> Reg<Mainclksela, RW>
Main clock A source select
Sourcepub const fn mainclkselb(self) -> Reg<Mainclkselb, RW>
pub const fn mainclkselb(self) -> Reg<Mainclkselb, RW>
Main clock source select
Sourcepub const fn pll0clksel(self) -> Reg<Pll0clksel, RW>
pub const fn pll0clksel(self) -> Reg<Pll0clksel, RW>
PLL0 clock source select
Sourcepub const fn pll1clksel(self) -> Reg<Pll1clksel, RW>
pub const fn pll1clksel(self) -> Reg<Pll1clksel, RW>
PLL1 clock source select
Sourcepub const fn usb0clksel(self) -> Reg<Usb0clksel, RW>
pub const fn usb0clksel(self) -> Reg<Usb0clksel, RW>
FS USB clock source select
Sourcepub const fn fcclksel(self, n: usize) -> Reg<Fcclksel, RW>
pub const fn fcclksel(self, n: usize) -> Reg<Fcclksel, RW>
Flexcomm Interface 0 clock source select for Fractional Rate Divider
Sourcepub const fn hslspiclksel(self) -> Reg<Hslspiclksel, RW>
pub const fn hslspiclksel(self) -> Reg<Hslspiclksel, RW>
HS LSPI clock source select
Sourcepub const fn mclkclksel(self) -> Reg<Mclkclksel, RW>
pub const fn mclkclksel(self) -> Reg<Mclkclksel, RW>
MCLK clock source select
Sourcepub const fn sdioclksel(self) -> Reg<Sdioclksel, RW>
pub const fn sdioclksel(self) -> Reg<Sdioclksel, RW>
SDIO clock source select
Sourcepub const fn systickclkdiv0(self) -> Reg<Systickclkdiv0, RW>
pub const fn systickclkdiv0(self) -> Reg<Systickclkdiv0, RW>
System Tick Timer divider for CPU0
Sourcepub const fn systickclkdiv1(self) -> Reg<Systickclkdiv1, RW>
pub const fn systickclkdiv1(self) -> Reg<Systickclkdiv1, RW>
System Tick Timer divider for CPU1
Sourcepub const fn traceclkdiv(self) -> Reg<Traceclkdiv, RW>
pub const fn traceclkdiv(self) -> Reg<Traceclkdiv, RW>
TRACE clock divider
Sourcepub const fn flexfrgctrl(self, n: usize) -> Reg<Flexfrgctrl, RW>
pub const fn flexfrgctrl(self, n: usize) -> Reg<Flexfrgctrl, RW>
Fractional rate divider for flexcomm 0
Sourcepub const fn flexfrgxctrl(self, n: usize) -> Reg<Flexfrgxctrl, RW>
pub const fn flexfrgxctrl(self, n: usize) -> Reg<Flexfrgxctrl, RW>
Peripheral reset control register
Sourcepub const fn usb0clkdiv(self) -> Reg<Usb0clkdiv, RW>
pub const fn usb0clkdiv(self) -> Reg<Usb0clkdiv, RW>
USB0 Clock divider
Sourcepub const fn sdioclkdiv(self) -> Reg<Sdioclkdiv, RW>
pub const fn sdioclkdiv(self) -> Reg<Sdioclkdiv, RW>
SDIO clock divider
Sourcepub const fn pll0clkdiv(self) -> Reg<Pll0clkdiv, RW>
pub const fn pll0clkdiv(self) -> Reg<Pll0clkdiv, RW>
PLL0 clock divider
Sourcepub const fn clockgenupdatelockout(self) -> Reg<Clockgenupdatelockout, RW>
pub const fn clockgenupdatelockout(self) -> Reg<Clockgenupdatelockout, RW>
Control clock configuration registers access (like xxxDIV, xxxSEL)
Sourcepub const fn usb0needclkctrl(self) -> Reg<Usb0needclkctrl, RW>
pub const fn usb0needclkctrl(self) -> Reg<Usb0needclkctrl, RW>
USB0 need clock control
Sourcepub const fn usb0needclkstat(self) -> Reg<Usb0needclkstat, RW>
pub const fn usb0needclkstat(self) -> Reg<Usb0needclkstat, RW>
USB0 need clock status
Sourcepub const fn usb1needclkctrl(self) -> Reg<Usb1needclkctrl, RW>
pub const fn usb1needclkctrl(self) -> Reg<Usb1needclkctrl, RW>
USB1 need clock control
Sourcepub const fn usb1needclkstat(self) -> Reg<Usb1needclkstat, RW>
pub const fn usb1needclkstat(self) -> Reg<Usb1needclkstat, RW>
USB1 need clock status
Sourcepub const fn sdioclkctrl(self) -> Reg<Sdioclkctrl, RW>
pub const fn sdioclkctrl(self) -> Reg<Sdioclkctrl, RW>
SDIO CCLKIN phase and delay control
Sourcepub const fn pll0sscg0(self) -> Reg<Pll0sscg0, RW>
pub const fn pll0sscg0(self) -> Reg<Pll0sscg0, RW>
PLL0 Spread Spectrum Wrapper control register 0
Sourcepub const fn pll0sscg1(self) -> Reg<Pll0sscg1, RW>
pub const fn pll0sscg1(self) -> Reg<Pll0sscg1, RW>
PLL0 Spread Spectrum Wrapper control register 1
Sourcepub const fn funcretentionctrl(self) -> Reg<Funcretentionctrl, RW>
pub const fn funcretentionctrl(self) -> Reg<Funcretentionctrl, RW>
Functional retention control register
Sourcepub const fn clock_ctrl(self) -> Reg<ClockCtrl, RW>
pub const fn clock_ctrl(self) -> Reg<ClockCtrl, RW>
Various system clock controls : Flash clock (48 MHz) control, clocks to Frequency Measures
Sourcepub const fn comp_int_ctrl(self) -> Reg<CompIntCtrl, RW>
pub const fn comp_int_ctrl(self) -> Reg<CompIntCtrl, RW>
Comparator Interrupt control
Sourcepub const fn comp_int_status(self) -> Reg<CompIntStatus, RW>
pub const fn comp_int_status(self) -> Reg<CompIntStatus, RW>
Comparator Interrupt status
Sourcepub const fn autoclkgateoverride(self) -> Reg<Autoclkgateoverride, RW>
pub const fn autoclkgateoverride(self) -> Reg<Autoclkgateoverride, RW>
Control automatic clock gating
Sourcepub const fn gpiopsync(self) -> Reg<Gpiopsync, RW>
pub const fn gpiopsync(self) -> Reg<Gpiopsync, RW>
Enable bypass of the first stage of synchonization inside GPIO_INT module
Sourcepub const fn debug_lock_en(self) -> Reg<DebugLockEn, RW>
pub const fn debug_lock_en(self) -> Reg<DebugLockEn, RW>
Control write access to security registers.
Sourcepub const fn debug_features(self) -> Reg<DebugFeatures, RW>
pub const fn debug_features(self) -> Reg<DebugFeatures, RW>
Cortex M33 (CPU0) and micro Cortex M33 (CPU1) debug features control.
Sourcepub const fn debug_features_dp(self) -> Reg<DebugFeaturesDp, RW>
pub const fn debug_features_dp(self) -> Reg<DebugFeaturesDp, RW>
Cortex M33 (CPU0) and micro Cortex M33 (CPU1) debug features control DUPLICATE register.
Sourcepub const fn debug_auth_beacon(self) -> Reg<DebugAuthBeacon, RW>
pub const fn debug_auth_beacon(self) -> Reg<DebugAuthBeacon, RW>
Debug authentication BEACON register
Sourcepub const fn device_id0(self) -> Reg<DeviceId0, R>
pub const fn device_id0(self) -> Reg<DeviceId0, R>
Device ID